import {
  TransitionalStyles
} from "./chunk.3M24Q4NP.js";
import {
  watch
} from "./chunk.TYGMNHNO.js";
import {
  GdsElement
} from "./chunk.LQSWYCMZ.js";
import {
  gdsCustomElement,
  html
} from "./chunk.MLXMQIEV.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "./chunk.SEHSDSX2.js";

// libs/core/src/primitives/field-base/field-base.ts
import { localized } from "@lit/localize";
import { property, query, state } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { map } from "lit/directives/map.js";

// libs/core/src/primitives/field-base/field-base.styles.ts
import { css } from "lit";
var styles = css`
  @layer base, a11y;

  @layer a11y {
    @media (prefers-reduced-motion: reduce) {
      .field {
        transition: none;
      }
    }
  }

  @layer base {
    * {
      box-sizing: border-box;
    }

    .field {
      display: flex;
      position: relative;
      align-items: center;
      justify-content: space-between;
      gap: var(--gds-space-xs);
      /* In Figma, the border overlaps with the padding, so we need to
         subtract 1px to replicate this in CSS */
      padding: calc(var(--gds-space-xs) - 1px) var(--gds-space-xs)
        calc(var(--gds-space-xs) - 1px) var(--gds-space-m);
      min-block-size: var(--gds-space-3xl);
      outline-style: solid;
      outline-width: 0;
      border-radius: var(--gds-space-xs);
      background: var(--gds-color-l3-background-secondary);
      color: var(--gds-color-l3-content-tertiary);
      border: var(--gds-space-4xs) solid var(--gds-color-l3-border-secondary);
      cursor: text;
      transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
      transition-duration: 368ms;
      transition-property: background-color, border-color, outline-color;
    }

    .field:focus-within {
      outline-width: var(--gds-space-3xs);
      outline-offset: var(--gds-space-3xs);
      outline-color: currentColor;
    }

    .field.small {
      gap: var(--gds-space-2xs);
      padding: calc(var(--gds-space-xs) - 1px) var(--gds-space-xs);
      min-block-size: var(--gds-space-xl);
    }

    /* In Figma, the icon button overlaps 4px with the padding. The rule
       below is there to replicate that so the field doesn't change height
       when the action button appears */
    .field.small slot[name='action']::slotted(*) {
      margin: calc(var(--gds-space-xs) / -0.5) 0;
    }

    .field.multiline {
      align-items: flex-start;
      padding: calc(var(--gds-space-s) - 1px) var(--gds-space-s)
        calc(var(--gds-space-s) - 1px) var(--gds-space-m);
      height: max-content;
    }

    .field.trail-slot-occupied,
    .field:not(.action-slot-occupied):not(.small) {
      padding: calc(var(--gds-space-xs) - 1px) var(--gds-space-m);
    }

    .field.disabled {
      background: var(--gds-color-l3-background-disabled);
      color: var(--gds-color-l3-content-disabled);
      border-color: transparent;
      pointer-events: none;
    }

    .field.invalid {
      background: var(--gds-color-l3-background-negative-secondary);
      border-color: var(--gds-color-l3-border-negative);
      color: var(--gds-color-l3-content-negative);
    }

    slot:not([name])::slotted(*) {
      color: currentColor;
    }

    .main-slot-wrap {
      display: flex;
      flex: 1;
    }

    .main-slot-wrap.multiline {
      height: max-content;
    }

    @media (hover: hover) {
      .field:hover {
        background: color-mix(
          in srgb,
          var(--gds-color-l3-background-secondary),
          var(--gds-color-l3-states-light-hover)
        );
      }

      .field.invalid:hover {
        background: color-mix(
          in srgb,
          var(--gds-color-l3-background-negative-secondary),
          var(--gds-color-l3-states-negative-hover)
        );
      }
    }

    slot[name='lead']::slotted([gds-element^='gds-icon-']) {
      align-items: center;
      justify-content: center;
      display: flex;
      min-width: var(--gds-space-l);
    }
  }
`;

// libs/core/src/primitives/field-base/field-base.ts
var _handleSlotChange, _renderFieldContents, renderFieldContents_fn, _renderSlotLead, renderSlotLead_fn, _renderSlotMain, renderSlotMain_fn, _renderSlotAction, renderSlotAction_fn, _renderSlotTrail, renderSlotTrail_fn;
var GdsFieldBase = class extends GdsElement {
  constructor() {
    super();
    __privateAdd(this, _renderFieldContents);
    __privateAdd(this, _renderSlotLead);
    __privateAdd(this, _renderSlotMain);
    __privateAdd(this, _renderSlotAction);
    __privateAdd(this, _renderSlotTrail);
    this.size = "large";
    this.multiline = false;
    this.disabled = false;
    this.invalid = false;
    this._leadSlotOccupied = false;
    this._trailSlotOccupied = false;
    this._actionSlotOccupied = false;
    __privateAdd(this, _handleSlotChange, (slotName, event) => {
      const slot = event.target;
      const assignedNodes = slot.assignedNodes({ flatten: true });
      const slotOccupied = assignedNodes.length > 0 && assignedNodes.some(
        (node) => {
          var _a;
          return node.nodeType === Node.ELEMENT_NODE || node.nodeType === Node.TEXT_NODE && ((_a = node.textContent) == null ? void 0 : _a.trim()) !== "";
        }
      );
      if (slotName === "lead") {
        this._leadSlotOccupied = slotOccupied;
      } else if (slotName === "trail") {
        this._trailSlotOccupied = slotOccupied;
      } else if (slotName === "action") {
        this._actionSlotOccupied = slotOccupied;
      } else if (slotName === "main") {
      }
    });
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-field-base");
  }
  render() {
    var _a;
    const classes = {
      invalid: (_a = this.invalid) != null ? _a : false,
      multiline: this.multiline,
      disabled: this.disabled,
      "lead-slot-occupied": this._leadSlotOccupied,
      "trail-slot-occupied": this._trailSlotOccupied,
      "action-slot-occupied": this._actionSlotOccupied,
      small: this.size === "small"
    };
    return html`
      <div class="field ${classMap(classes)}" part="_base">
        ${__privateMethod(this, _renderFieldContents, renderFieldContents_fn).call(this)}
      </div>
    `;
  }
  _handleDisabledChange() {
    if (this.disabled) {
      this.setAttribute("inert", "");
    } else {
      this.removeAttribute("inert");
    }
  }
};
_handleSlotChange = new WeakMap();
_renderFieldContents = new WeakSet();
renderFieldContents_fn = function() {
  const elements = [
    __privateMethod(this, _renderSlotLead, renderSlotLead_fn).call(this),
    __privateMethod(this, _renderSlotMain, renderSlotMain_fn).call(this),
    __privateMethod(this, _renderSlotAction, renderSlotAction_fn).call(this),
    __privateMethod(this, _renderSlotTrail, renderSlotTrail_fn).call(this)
  ];
  return html`${map(elements, (el) => el)}`;
};
_renderSlotLead = new WeakSet();
renderSlotLead_fn = function() {
  return html` <slot
      name="lead"
      @slotchange=${(e) => __privateGet(this, _handleSlotChange).call(this, "lead", e)}
    ></slot>`;
};
_renderSlotMain = new WeakSet();
renderSlotMain_fn = function() {
  return html`<div
      class="main-slot-wrap ${classMap({ multiline: this.multiline })}"
    >
      <slot
        @slotchange=${(e) => __privateGet(this, _handleSlotChange).call(this, "main", e)}
      ></slot>
    </div>`;
};
_renderSlotAction = new WeakSet();
renderSlotAction_fn = function() {
  return html`
      <slot
        name="action"
        @slotchange=${(e) => __privateGet(this, _handleSlotChange).call(this, "action", e)}
      ></slot>
    `;
};
_renderSlotTrail = new WeakSet();
renderSlotTrail_fn = function() {
  return html`
      <slot
        name="trail"
        @slotchange=${(e) => __privateGet(this, _handleSlotChange).call(this, "trail", e)}
      ></slot>
    `;
};
GdsFieldBase.styles = [styles];
__decorateClass([
  property()
], GdsFieldBase.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean })
], GdsFieldBase.prototype, "multiline", 2);
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsFieldBase.prototype, "disabled", 2);
__decorateClass([
  property({ type: Boolean })
], GdsFieldBase.prototype, "invalid", 2);
__decorateClass([
  query("slot:not([name])")
], GdsFieldBase.prototype, "_mainSlotElement", 2);
__decorateClass([
  state()
], GdsFieldBase.prototype, "_leadSlotOccupied", 2);
__decorateClass([
  state()
], GdsFieldBase.prototype, "_trailSlotOccupied", 2);
__decorateClass([
  state()
], GdsFieldBase.prototype, "_actionSlotOccupied", 2);
__decorateClass([
  watch("disabled")
], GdsFieldBase.prototype, "_handleDisabledChange", 1);
GdsFieldBase = __decorateClass([
  gdsCustomElement("gds-field-base"),
  localized()
], GdsFieldBase);

export {
  GdsFieldBase
};
